@@ -2,7 +2,7 @@
  * Copyright (C) Microsoft. All rights reserved.
  * Licensed under the MIT license. See LICENSE.txt file in the project root for full license information.
  *
- * =+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+
+ * =+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+
  *
  * HTTP Library: Client-side APIs.
  *
@@ -10,15 +10,15 @@
  *
  * For the latest on this and related APIs, please see: https://github.com/Microsoft/cpprestsdk
  *
- * =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
+ * =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
  ****/
 
 #include "stdafx.h"
-#include <sstream>
 
-#include "../common/internal_http_helpers.h"
 #include "../common/connection_pool_helpers.h"
+#include "../common/internal_http_helpers.h"
 #include "cpprest/asyncrt_utils.h"
+#include <sstream>
 
 #if defined(__clang__)
 #pragma clang diagnostic push
@@ -39,9 +39,9 @@
 #error "Cpp rest SDK requires c++11 smart pointer support from boost"
 #endif
 
+#include "../common/x509_cert_utilities.h"
 #include "cpprest/base_uri.h"
 #include "cpprest/details/http_helpers.h"
-#include "../common/x509_cert_utilities.h"
 #include "http_client_impl.h"
 #include "pplx/threadpool.h"
 #include <memory>
@@ -1322,7 +1322,39 @@ private:
             // cancellation registration to maintain the old state.
             // This also obtains a new connection from pool.
             auto new_ctx = create_request_context(m_http_client, m_request);
-            new_ctx->m_request._get_impl()->instream().seek(0);
+
+            // If the request contains a valid instream, we try to rewind it to
+            // replay the just-failed request. Otherwise we assume that no data
+            // was sent in the first place.
+            const auto& instream = new_ctx->m_request._get_impl()->instream();
+            if (instream)
+            {
+                // As stated in the commit message of f4f2348, we might encounter
+                // streams that are not capable of rewinding and hence resending the
+                // request is not possible. We cannot recover from this condition and
+                // need to escalate it to the using code.
+                if (!instream.can_seek())
+                {
+                    report_error("cannot rewind input stream for connection re-establishment",
+                                 ec,
+                                 httpclient_errorcode_context::readheader);
+                    return;
+                }
+
+                try
+                {
+                    // Rewinding the stream might throw, in which case we cannot do the
+                    // connection re-establishment transparently. I.e. report the exception
+                    // to the calling code.
+                    instream.seek(0);
+                }
+                catch (...)
+                {
+                    report_exception(std::current_exception());
+                    return;
+                }
+            }
+
             new_ctx->m_request_completion = m_request_completion;
             new_ctx->m_cancellationRegistration = m_cancellationRegistration;
 
@@ -1906,7 +1938,7 @@ pplx::task<http_response> asio_client::propagate(http_request request)
 
     return result_task;
 }
-}
-}
-}
-} // namespaces
+} // namespace details
+} // namespace client
+} // namespace http
+} // namespace web
